==> haskell-crypto-api-tests-0.3-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-api-tests
version:              0.3
visibility:           public
id:                   crypto-api-tests-0.3-BjON0f149s85BuNIS5CUKY
key:                  crypto-api-tests-0.3-BjON0f149s85BuNIS5CUKY
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             http://trac.haskell.org/crypto-api/wiki
synopsis:             A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).

category:             Data, Cryptography
abi:                  8e2fb13a14df54503ebbf2005d6f3da6
exposed:              True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish

hidden-modules:       Paths_crypto_api_tests
import-dirs:          /usr/lib/ghc-8.8.3/site-local/crypto-api-tests-0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/crypto-api-tests-0.3
hs-libraries:         HScrypto-api-tests-0.3-BjON0f149s85BuNIS5CUKY
depends:
    HUnit-1.6.0.0-I2MmbBeZarmFuj7otDSV2j
    QuickCheck-2.13.2-6fFQIFT0E4j6TGV1ji065T base-4.13.0.0
    bytestring-0.10.10.0 cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs
    crypto-api-0.13.3-C5w78A3CW33UPNf3e76TZ directory-1.3.6.0
    filepath-1.4.2.1 test-framework-0.8.2.0-KfOHfUEpvFL4HROjRXzfJC
    test-framework-hunit-0.3.0.2-IlutgmwMxFyHkcZ9Khwgjg
    test-framework-quickcheck2-0.3.0.5-Cl3qkucxP4H9aud2mPgWh5

haddock-interfaces:
    /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock

haddock-html:         /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-api-tests
version:              0.3
visibility:           public
id:                   crypto-api-tests-0.3-DtUWQqnSMuaKFiUk4Ru5Bv
key:                  crypto-api-tests-0.3-DtUWQqnSMuaKFiUk4Ru5Bv
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             http://trac.haskell.org/crypto-api/wiki
synopsis:             A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).

category:             Data, Cryptography
abi:                  15f15a6133784c3f0268a81271e28d98
exposed:              True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish

hidden-modules:       Paths_crypto_api_tests
import-dirs:          /usr/lib/ghc-8.8.3/site-local/crypto-api-tests-0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/crypto-api-tests-0.3
hs-libraries:         HScrypto-api-tests-0.3-DtUWQqnSMuaKFiUk4Ru5Bv
depends:
    HUnit-1.6.0.0-8Ww89t5IMRZ6CRK74qsBa0
    QuickCheck-2.13.2-6162FC0NJtEaNoo7xqAu9 base-4.13.0.0
    bytestring-0.10.10.0 cereal-0.5.8.1-4ELvUVAvdXS1XtXORHyQWs
    crypto-api-0.13.3-C5w78A3CW33UPNf3e76TZ directory-1.3.6.0
    filepath-1.4.2.1 test-framework-0.8.2.0-4HIAO4sod5REcbDIoWygFv
    test-framework-hunit-0.3.0.2-8OzuvPHOeQYFW0eckXL78Y
    test-framework-quickcheck2-0.3.0.5-3RiApeoYy7rFqUAnDqak0l

haddock-interfaces:
    /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock

haddock-html:         /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
